@@ -212,6 +212,11 @@ ncatt_put_inner = function( ncid, varid, attname, attval, prec=NA, verbose=FALSE
 		}
 
 	else if( storage.mode(attval) == "character") {
+
+		if( verbose ) 
+			print(paste0("Calling R_nc4_put_att_text with name >", attname, "< att_len: ", 
+				as.integer(length(attval)), ' value: >', attval, '<' ))
+
 		rv <- .C("R_nc4_put_att_text",
 			as.integer(ncid),
 			as.integer(varid),
@@ -249,8 +254,10 @@ ncatt_put_inner = function( ncid, varid, attname, attval, prec=NA, verbose=FALSE
 	else
 		stop(paste("ncatt_put: error, passed an attribute with a storage mode not handled.  Att name:",attname,"Att value:",attval,"Storage mode passed:",storage.mode(attval),".  Handled types: integer double character"))
 
-	if( ! definemode )
-		nc_enddef(ncid)
+	if( ! definemode ) {
+		if( nc_enddef( ncid ) != 0 ) 
+			stop(paste("Error, nc_enddef returned an error!"))
+		}
 }
 
 #===================================================================================================
